/**
 * This class represents an email message.  It provides methods 
 * to retrieve the full header, the short header (To, From, Date, Subject),
 * a truncated header, and several 'pretty' views of the mail message.
 */
public class MailMessage {

    private String contents;
    private String headers;
    
    /**
     * Construct an empty mail message
     */
    public MailMessage( ) {
        headers = "";
        contents = null;
    }
    
    /**
     * Add new lines to the mail message.  The first lines added
     * are for the header.  The later lines denote content.  The header 
     * and content are separated by an empty string.
     */
    public void append( String newLine ) {
        if ( contents == null ) {
            if ( newLine.equals("") ) {
                contents = newLine;
            } else {
                headers = headers + newLine + "\n";
            }
        } else {
            contents = contents + newLine + "\n";
        }
    }
    
    /**
     * Return the 'prefix' header of the message.
     * For example, 'prefix' might be the "To:" or "From:"
     * field of the header.
     */
    private String getHeader( String prefix ) {
        int start = headers.indexOf( prefix );
        if ( start >= 0 ) {
            int end = headers.indexOf( "\n", start );
            return headers.substring( start, end );
        } else {
            return "";
        }
    }
    
    /**
     * Return a truncated header for 'prefix' with length
     * at most 'len'.
     */
    private String truncatedHeader( String prefix, int len ) {
        String result = getHeader( prefix );
        if ( result.length() > prefix.length() ) {
            result = result.substring( prefix.length() );
        }
        while ( result.length() < len ) {
            result = result + "     ";
        }
        return result.substring( 0, len );
    }
    
    /**
     * Return the standard header fields, separated by newlines.
     */
    private String shortHeaders() {
        return getHeader( "From: " ) + "\n" +
                 getHeader( "To: " ) + "\n" +
                   getHeader( "Subject: " ) + "\n" +
                      getHeader( "Date: " ) + "\n\n";     
    }
    
    /**
     * Return a summary of the mail message, suitable for displaying
     * inside a combo box.
     */
    public String shortSummary() {
        return truncatedHeader( "Date: ", 16 ) + " | " + 
                   truncatedHeader( "From: ", 25 ) + " | " + 
                       truncatedHeader( "Subject: ", 33 );
    }
    
    /**
     * Return a pretty version of the mail message including the short
     * headers and the message content.
     */
    public String toString( ) {
        return shortHeaders() + "\n" + contents.toString();
    }        
}